@@ -21,10 +21,50 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
-from .control import Control, ControlPosition, _get_color, _get_title_position, _get_label_style
+from .control import Control, ControlPosition, ControlConfig, _get_color, _get_title_position, _get_label_style
 from .enums import Color, LabelStyle, TitlePosition
 
 
+class LabelConfig(ControlConfig):
+    """LabelConfig"""
+    def __init__(
+        self,
+        control_id: str,
+        title: str,
+        title_position: TitlePosition,
+        color: Color,
+        style: LabelStyle,
+        control_position: ControlPosition
+    ) -> None:
+        super().__init__(control_id, title, control_position, title_position)
+        self.cfg["style"] = style.value
+        self.cfg["color"] = str(color.value)
+
+    @classmethod
+    def from_dict(cls, cfg_dict: dict):
+        """Instantiates LabelConfig from cfg dictionary
+
+        Parameters
+        ----------
+        cfg_dict : dict
+            A dictionary usually loaded from a config json from IoTDashboard App
+
+        Returns
+        -------
+        LabelConfig
+        """
+        tmp_cls = cls(
+            cfg_dict["controlID"],
+            cfg_dict["title"],
+            _get_title_position(cfg_dict["titlePosition"]),
+            _get_color(cfg_dict["color"]),
+            _get_label_style(cfg_dict["style"]),
+            ControlPosition(cfg_dict["xPositionRatio"], cfg_dict["yPositionRatio"], cfg_dict["widthRatio"], cfg_dict["heightRatio"])
+        )
+        tmp_cls.parent_id = cfg_dict["parentID"]
+        return tmp_cls
+
+
 class Label(Control):
     """A Config only control"""
 
@@ -54,9 +94,16 @@ class Label(Control):
         style : LabelStyle, optional
             Style of label to be displayed, by default LabelStyle.BASIC
         """
-        super().__init__("LBL", control_id, title=title, control_position=control_position, title_position=title_position)
-        self.color = color
-        self.style = style
+        super().__init__("LBL", control_id)
+        control_config = LabelConfig(
+            control_id,
+            title,
+            title_position,
+            color,
+            style,
+            control_position
+        )
+        self._cfg_columnar.append(control_config)
         self._state_str = ""
 
     @classmethod
@@ -82,35 +129,3 @@ class Label(Control):
         )
         tmp_cls.parent_id = cfg_dict["parentID"]
         return tmp_cls
-
-    @property
-    def style(self) -> LabelStyle:
-        """Label style
-
-        Returns
-        -------
-        LabelStyle
-            Style of label to display
-        """
-        return self._style
-
-    @style.setter
-    def style(self, val: LabelStyle):
-        self._style = val
-        self._cfg["style"] = val.value
-
-    @property
-    def color(self) -> Color:
-        """Color
-
-        Returns
-        -------
-        Color
-            Clor of the label
-        """
-        return self._color
-
-    @color.setter
-    def color(self, val: Color):
-        self._color = val
-        self._cfg["color"] = str(val.value)
